async fn handle_crypto_sync(client: &Client, data: &CryptoSyncData)Expand description
Runs the key management sync work for the given sync data.
async fn handle_crypto_sync(client: &Client, data: &CryptoSyncData)Runs the key management sync work for the given sync data.