async fn is_replayed_state(client: &Client, data: &CryptoSyncData) -> boolExpand description
Whether the sync carries a state that constitutes a cryptographic downgrade
Currently, the only downgrade defined is a V2 -> V1 encryption downgrade
async fn is_replayed_state(client: &Client, data: &CryptoSyncData) -> boolWhether the sync carries a state that constitutes a cryptographic downgrade
Currently, the only downgrade defined is a V2 -> V1 encryption downgrade